..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

API Docs
========

.. automodule:: invenio_records.ext
   :members:

Record API
----------
.. automodule:: invenio_records.api
   :members:

Configuration
-------------
.. automodule:: invenio_records.config
   :members:

Errors
------
.. automodule:: invenio_records.errors
   :members:

Models
------
.. automodule:: invenio_records.models
   :members:

Signals
-------
.. automodule:: invenio_records.signals
   :members:

Dumpers/Loaders
---------------
.. automodule:: invenio_records.dumpers
   :members:

Extensions
----------
.. automodule:: invenio_records.extensions
   :members:
   :special-members:
   :exclude-members: __weakref__

System Fields
-------------
.. automodule:: invenio_records.systemfields
   :members:
   :special-members:
   :exclude-members: __weakref__
